<?php

namespace Netgen\TagsBundle\Controller\Admin;

use Netgen\TagsBundle\API\Repository\TagsService;
use Pagerfanta\Adapter\AdapterInterface;
use Symfony\Component\HttpFoundation\Request;

class SearchController extends Controller
{
    /**
     * @var \Netgen\TagsBundle\API\Repository\TagsService
     */
    protected $tagsService;

    /**
     * @var \Pagerfanta\Adapter\AdapterInterface
     */
    protected $adapter;

    /**
     * @var int
     */
    protected $pagerLimit = 25;

    /**
     * SearchController constructor.
     *
     * @param \Netgen\TagsBundle\API\Repository\TagsService $tagsService
     */
    public function __construct(TagsService $tagsService)
    {
        $this->tagsService = $tagsService;
        $this->adapter = $adapter;
    }

    /**
     * Sets the pager limit.
     *
     * @param int $pagerLimit
     */
    public function setPagerLimit($pagerLimit)
    {
        $this->pagerLimit = (int)$pagerLimit;
    }

    /**
     * Rendering a view which shows a tag search page.
     *
     * @param \Symfony\Component\HttpFoundation\Request $request
     *
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function searchTagsAction(Request $request)
    {
        $this->denyAccessUnlessGranted('ez:tags:read');

        $searchText = trim($request->query->get('searchText'));

        $currentPage = (int)$request->query->get('page');
        $pager = $this->createPager($this->adapter, $currentPage, $this->pagerLimit);

        return $this->render(
            'NetgenTagsBundle:admin/search:index.html.twig',
            array(
                'searchText' => $searchText,
            )
        );
    }
}
